
From: Jesper Juhl <juhl-lkml@dif.dk>

This patch modifies a few of the printk() loglevels used in init/main.c in
an attempt to make them a bit more appropriate.

The default loglevel is KERN_WARNING, but a few printk's without explicit
loglevel are not (in my oppinion) warnings, so add proper warning levels -
for instance; telling the user how many CPU's were brought up is hardly a
warning, make it KERN_INFO instead.  The initial printing of linux_banner
is not a warning condition, I'd say it's more of a NOTICE or even INFO
condition - I've made it KERN_NOTICE just as the printing of the kernel
command line.  A few printk's without explicit loglevel do match the
default one, but I've made them explicit (the default could change in the
future, and if it does then explicitly setting the proper loglevel is a
nice thing).

Signed-off-by: Jesper Juhl <juhl-lkml@dif.dk>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/init/main.c |    9 +++++----
 1 files changed, 5 insertions(+), 4 deletions(-)

diff -puN init/main.c~make-loglevels-in-init-mainc-a-little-more-sane init/main.c
--- 25/init/main.c~make-loglevels-in-init-mainc-a-little-more-sane	2005-01-23 01:47:55.419453560 -0800
+++ 25-akpm/init/main.c	2005-01-23 01:48:15.343424656 -0800
@@ -348,7 +348,7 @@ static void __init smp_init(void)
 	}
 
 	/* Any cleanup work */
-	printk("Brought up %ld CPUs\n", (long)num_online_cpus());
+	printk(KERN_INFO "Brought up %ld CPUs\n", (long)num_online_cpus());
 	smp_cpus_done(max_cpus);
 #if 0
 	/* Get other processors into their bootup holding patterns. */
@@ -429,6 +429,7 @@ asmlinkage void __init start_kernel(void
  */
 	lock_kernel();
 	page_address_init();
+	printk(KERN_NOTICE);
 	printk(linux_banner);
 	setup_arch(&command_line);
 	setup_per_cpu_areas();
@@ -453,7 +454,7 @@ asmlinkage void __init start_kernel(void
 	build_all_zonelists();
 	page_alloc_init();
 	trap_init();
-	printk("Kernel command line: %s\n", saved_command_line);
+	printk(KERN_NOTICE "Kernel command line: %s\n", saved_command_line);
 	parse_early_param();
 	parse_args("Booting kernel", command_line, __start___param,
 		   __stop___param - __start___param,
@@ -561,7 +562,7 @@ static void __init do_initcalls(void)
 			local_irq_enable();
 		}
 		if (msg) {
-			printk("error in initcall at 0x%p: "
+			printk(KERN_WARNING "error in initcall at 0x%p: "
 				"returned with %s\n", *call, msg);
 		}
 	}
@@ -682,7 +683,7 @@ static int init(void * unused)
 	numa_default_policy();
 
 	if (sys_open((const char __user *) "/dev/console", O_RDWR, 0) < 0)
-		printk("Warning: unable to open an initial console.\n");
+		printk(KERN_WARNING "Warning: unable to open an initial console.\n");
 
 	(void) sys_dup(0);
 	(void) sys_dup(0);
_
